import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/* eslint-disable react/no-array-index-key */
import React, { createElement, isValidElement } from 'react';
import Grid from '@mui/material/Grid';
import Typography from '@mui/material/Typography';
import makeStyles from '@mui/styles/makeStyles';
import createPConnectComponent from '../../../bridge/react_pconnect';
import { format } from '../../helpers/formatters';
const useStyles = makeStyles(theme => ({
    root: {
        paddingRight: theme.spacing(1),
        paddingLeft: theme.spacing(1),
        paddingTop: theme.spacing(1),
        paddingBottom: theme.spacing(1),
        marginRight: theme.spacing(1),
        marginLeft: theme.spacing(1),
        marginTop: theme.spacing(1),
        marginBottom: theme.spacing(1)
    },
    fieldLabel: {
        display: 'block',
        fontWeight: 400,
        color: theme.palette.text.secondary
    },
    fieldValue: {
        fontWeight: 400,
        color: theme.palette.text.primary
    }
}));
export default function DetailsFields(props) {
    // const componentName = "DetailsFields";
    const { fields = [] } = props;
    const classes = useStyles();
    const fieldComponents = [];
    fields?.forEach((field, index) => {
        const thePConn = field.getPConnect();
        const theCompType = thePConn.getComponentName().toLowerCase();
        const { label } = thePConn.getConfigProps();
        const configObj = thePConn?.getReferencedView();
        configObj.config.readOnly = true;
        configObj.config.displayMode = 'DISPLAY_ONLY';
        const propToUse = { ...thePConn.getInheritedProps() };
        configObj.config.label = theCompType === 'reference' ? propToUse?.label : label;
        fieldComponents.push({
            type: theCompType,
            label,
            value: _jsx(React.Fragment, { children: createElement(createPConnectComponent(), thePConn.getReferencedViewPConnect()) }, index)
        });
    });
    function getGridItemLabel(field, keyVal) {
        const dispValue = field.label;
        return (_jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'body2', component: 'span', className: `${classes.fieldLabel}`, children: dispValue }) }, keyVal));
    }
    function formatItemValue(inField) {
        const { type, value } = inField;
        let formattedVal = value;
        // eslint-disable-next-line sonarjs/no-small-switch
        switch (type) {
            case 'date':
                formattedVal = format(value, type);
                break;
            default:
                // No match means we return the value as we received it
                break;
        }
        // Finally, if the value is undefined or an empty string, we want to display it as "---"
        if (formattedVal === undefined || formattedVal === '') {
            formattedVal = '---';
        }
        return formattedVal;
    }
    function getGridItemValue(field, keyVal) {
        const formattedValue = formatItemValue(field);
        return (_jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'body2', component: 'span', className: classes.fieldValue, children: formattedValue }) }, keyVal));
    }
    function getGridItem(field, keyVal) {
        return (_jsx(Grid, { item: true, xs: 12, children: _jsx(Typography, { variant: 'body2', component: 'span', className: classes.fieldValue, children: field?.value }) }, keyVal));
    }
    function getGridItems() {
        const gridItems = fieldComponents.map((field, index) => {
            if (field?.type === 'reference') {
                return field?.value;
            }
            if (isValidElement(field?.value)) {
                return (_jsx(Grid, { container: true, spacing: 1, style: { padding: '4px 0px' }, children: getGridItem(field, `${index}-item`) }, index));
            }
            return (_jsxs(Grid, { container: true, spacing: 1, style: { padding: '4px 0px' }, children: [getGridItemLabel(field, `${index}-label`), getGridItemValue(field, `${index}-value`)] }, index));
        });
        return gridItems;
    }
    return _jsx(_Fragment, { children: getGridItems() });
}
//# sourceMappingURL=DetailsFields.js.map