import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React, { useState } from 'react';
import TextField from '@mui/material/TextField';
import Popover from '@mui/material/Popover';
import Grid from '@mui/material/Grid';
import Typography from '@mui/material/Typography';
import makeStyles from '@mui/styles/makeStyles';
import Utils from '../../helpers/utils';
const useStyles = makeStyles(theme => ({
    root: {
        padding: theme.spacing(1),
        margin: theme.spacing(1)
    },
    popover: {
        padding: theme.spacing(1),
        margin: theme.spacing(1)
    }
}));
export default function Operator(props) {
    // const componentName = "Operator";
    const classes = useStyles();
    const fieldLabel = props?.label?.toLowerCase();
    const displayLabel = props?.displayLabel?.toLowerCase();
    let caseOpLabel = '---';
    let caseOpName = '---';
    let caseOpId = '';
    let caseTime = '';
    if (fieldLabel === 'create operator' || displayLabel === 'create operator') {
        caseOpLabel = props.createLabel;
        caseOpName = props.createOperator.userName;
        caseTime = props.createDateTime;
        caseOpId = props.createOperator.userId;
    }
    else if (fieldLabel === 'update operator' || displayLabel === 'update operator') {
        caseOpLabel = props.updateLabel;
        caseOpName = props.updateOperator.userName;
        caseTime = props.updateDateTime;
        caseOpId = props.updateOperator.userId;
    }
    // Popover-related
    const [popoverAnchorEl, setPopoverAnchorEl] = useState(null);
    const [popoverFields, setPopoverFields] = useState([]);
    const popoverOpen = Boolean(popoverAnchorEl);
    const popoverId = popoverOpen ? 'operator-details-popover' : undefined;
    const handlePopoverClose = () => {
        setPopoverAnchorEl(null);
    };
    function showOperatorDetails(event) {
        const operatorPreviewPromise = PCore.getUserApi().getOperatorDetails(caseOpId);
        const localizedVal = PCore.getLocaleUtils().getLocaleValue;
        const localeCategory = 'Operator';
        operatorPreviewPromise.then((res) => {
            const fillerString = '---';
            let fields = [];
            if (res.data && res.data.pyOperatorInfo && res.data.pyOperatorInfo.pyUserName) {
                fields = [
                    {
                        id: 'pyPosition',
                        name: localizedVal('Position', localeCategory),
                        value: res.data.pyOperatorInfo.pyPosition ? res.data.pyOperatorInfo.pyPosition : fillerString
                    },
                    {
                        id: 'pyOrganization',
                        name: localizedVal('Organization', localeCategory),
                        value: res.data.pyOperatorInfo.pyOrganization ? res.data.pyOperatorInfo.pyOrganization : fillerString
                    },
                    {
                        id: 'ReportToUserName',
                        name: localizedVal('Reports to', localeCategory),
                        value: res.data.pyOperatorInfo.pyReportToUserName ? res.data.pyOperatorInfo.pyReportToUserName : fillerString
                    },
                    {
                        id: 'pyTelephone',
                        name: localizedVal('Telephone', localeCategory),
                        value: res.data.pyOperatorInfo.pyTelephone ? (_jsx("a", { href: `tel:${res.data.pyOperatorInfo.pyTelephone}`, children: res.data.pyOperatorInfo.pyTelephone })) : (fillerString)
                    },
                    {
                        id: 'pyEmailAddress',
                        name: localizedVal('Email address', localeCategory),
                        value: res.data.pyOperatorInfo.pyEmailAddress ? (_jsx("a", { href: `mailto:${res.data.pyOperatorInfo.pyEmailAddress}`, children: res.data.pyOperatorInfo.pyEmailAddress })) : (fillerString)
                    }
                ];
            }
            else {
                // eslint-disable-next-line no-console
                console.log(`Operator: PCore.getUserApi().getOperatorDetails(${caseOpId}); returned empty res.data.pyOperatorInfo.pyUserName - adding default`);
                fields = [
                    {
                        id: 'pyPosition',
                        name: localizedVal('Position', localeCategory),
                        value: fillerString
                    },
                    {
                        id: 'pyOrganization',
                        name: localizedVal('Organization', localeCategory),
                        value: fillerString
                    },
                    {
                        id: 'ReportToUserName',
                        name: localizedVal('Reports to', localeCategory),
                        value: fillerString
                    },
                    {
                        id: 'pyTelephone',
                        name: localizedVal('Telephone', localeCategory),
                        value: fillerString
                    },
                    {
                        id: 'pyEmailAddress',
                        name: localizedVal('Email address', localeCategory),
                        value: fillerString
                    }
                ];
            }
            // Whatever the fields are, update the component's popoverFields
            setPopoverFields(fields);
        });
        setPopoverAnchorEl(event.currentTarget);
    }
    function getPopoverGrid() {
        // return popoverFields.map((field) => {
        //   return <div className={classes.popover}>{field.name}: {field.value}</div>
        // })
        if (popoverFields.length === 0) {
            return;
        }
        // There are fields, so build the grid.
        return (_jsxs(Grid, { container: true, className: classes.popover, spacing: 1, children: [_jsx(Grid, { item: true, xs: 12, children: _jsx(Typography, { variant: 'h6', children: caseOpName }) }), popoverFields.map(field => {
                    return (_jsx(React.Fragment, { children: _jsxs(Grid, { container: true, item: true, xs: 12, spacing: 1, children: [_jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'caption', children: field.name }) }), _jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'subtitle2', children: field.value }) })] }) }, field.id));
                })] }));
    }
    // End of popover-related
    return (_jsxs(_Fragment, { children: [_jsx(TextField, { variant: 'standard', defaultValue: caseOpName, label: caseOpLabel, onClick: showOperatorDetails, InputProps: {
                    readOnly: true,
                    disableUnderline: true,
                    inputProps: { style: { cursor: 'pointer' } }
                } }), _jsx("br", {}), Utils.generateDateTime(caseTime, 'DateTime-Since'), _jsx(Popover, { id: popoverId, open: popoverOpen, anchorEl: popoverAnchorEl, onClose: handlePopoverClose, anchorOrigin: { vertical: 'bottom', horizontal: 'center' }, transformOrigin: { vertical: 'top', horizontal: 'center' }, PaperProps: { style: { maxWidth: '45ch' } }, children: getPopoverGrid() })] }));
}
//# sourceMappingURL=Operator.js.map