import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState } from 'react';
import { Button, Grid, IconButton, Snackbar } from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import './CancelAlert.css';
export default function CancelAlert(props) {
    const { heading, content, getPConnect, itemKey: containerItemID, hideDelete, isDataObject, skipReleaseLockRequest, dismiss } = props;
    const actionsAPI = getPConnect().getActionsApi();
    const containerManagerAPI = getPConnect().getContainerManager();
    const isLocalAction = getPConnect().getValue(PCore.getConstants().CASE_INFO.IS_LOCAL_ACTION);
    // @ts-ignore - Property 'options' is private and only accessible within class 'C11nEnv'.
    const isBulkAction = getPConnect()?.options?.isBulkAction;
    const localizedVal = PCore.getLocaleUtils().getLocaleValue;
    const broadCastUtils = PCore.getCoexistenceManager().getBroadcastUtils();
    const isReverseCoexistence = broadCastUtils.isReverseCoexistenceCaseLoaded();
    const localeCategory = 'ModalContainer';
    const btnIds = {
        SAVE_AND_CLOSE: 'saveAndClose',
        CONTINUE_WORKING: 'continueWorking',
        DELETE: 'delete'
    };
    const [buttonsState, setButtonsState] = useState({
        [btnIds.SAVE_AND_CLOSE]: false,
        [btnIds.DELETE]: false
    });
    const [showSnackbar, setShowSnackbar] = useState(false);
    const [snackbarMessage, setSnackbarMessage] = useState('');
    function disableButton(id) {
        setButtonsState(prevState => ({
            ...prevState,
            [id]: true
        }));
    }
    function enableButton(id) {
        setButtonsState(prevState => ({
            ...prevState,
            [id]: false
        }));
    }
    function cancelHandler() {
        if (isReverseCoexistence) {
            dismiss(true);
            // @ts-ignore - An argument for 'payload' was not provided.
            PCore.getPubSubUtils().publish(PCore.getConstants().PUB_SUB_EVENTS.REVERSE_COEXISTENCE_EVENTS.HANDLE_DISCARD);
        }
        else if (!isDataObject && !isLocalAction && !isBulkAction) {
            disableButton(btnIds.DELETE);
            actionsAPI
                .deleteCaseInCreateStage(containerItemID, hideDelete)
                .then(() => {
                // @ts-ignore - An argument for 'payload' was not provided.
                PCore.getPubSubUtils().publish(PCore.getConstants().PUB_SUB_EVENTS.EVENT_CANCEL);
            })
                .catch(() => {
                setSnackbarMessage(localizedVal('Delete failed.', localeCategory));
                setShowSnackbar(true);
            })
                .finally(() => {
                enableButton(btnIds.DELETE);
                dismiss(true);
            });
        }
        else if (isLocalAction) {
            dismiss(true);
            actionsAPI.cancelAssignment(containerItemID);
        }
        else if (isBulkAction) {
            dismiss(true);
            actionsAPI.cancelBulkAction(containerItemID);
        }
        else {
            dismiss(true);
            // @ts-ignore - Argument of type '{ containerItemID: string; skipReleaseLockRequest: any; }' is not assignable to parameter of type 'ContainerInfo'.
            containerManagerAPI.removeContainerItem({ containerItemID, skipReleaseLockRequest });
        }
    }
    function handleSnackbarClose(event, reason) {
        if (reason === 'clickaway') {
            return;
        }
        setShowSnackbar(false);
    }
    const leftButton = (_jsx(Button, { name: btnIds.CONTINUE_WORKING, variant: 'contained', color: 'secondary', onClick: () => {
            dismiss();
            if (isReverseCoexistence) {
                broadCastUtils.setCallBackFunction(null);
                broadCastUtils.setIsDirtyDialogActive(false);
            }
        }, children: localizedVal('Go back', localeCategory) }));
    const rightButton = (_jsx(Button, { name: btnIds.DELETE, variant: 'contained', color: 'primary', disabled: buttonsState[btnIds.DELETE], onClick: cancelHandler, children: localizedVal('Discard', localeCategory) }));
    return (_jsxs(_Fragment, { children: [_jsx("div", { className: 'cancel-alert-background', children: _jsxs("div", { className: 'cancel-alert-top', children: [_jsx("h3", { children: localizedVal(heading, localeCategory) }), _jsx("div", { children: _jsx("p", { children: localizedVal(content, localeCategory) }) }), _jsx("div", { className: 'action-controls', children: _jsxs(Grid, { container: true, spacing: 4, justifyContent: 'space-between', children: [_jsx(Grid, { item: true, children: leftButton }), _jsx(Grid, { item: true, children: rightButton })] }) })] }) }), _jsx(Snackbar, { open: showSnackbar, autoHideDuration: 3000, onClose: handleSnackbarClose, message: snackbarMessage, action: _jsx(IconButton, { size: 'small', "aria-label": 'close', color: 'inherit', onClick: handleSnackbarClose, children: _jsx(CloseIcon, { fontSize: 'small' }) }) })] }));
}
//# sourceMappingURL=CancelAlert.js.map