import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/* eslint-disable react/no-array-index-key */
import { useState, useEffect } from 'react';
import { Checkbox, FormControl, FormControlLabel, FormGroup, FormHelperText, FormLabel } from '@mui/material';
import makeStyles from '@mui/styles/makeStyles';
import handleEvent from '../../helpers/event-utils';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
import { insertInstruction, deleteInstruction, updateNewInstuctions } from '../../helpers/instructions-utils';
const useStyles = makeStyles(() => ({
    checkbox: {
        display: 'flex',
        flexDirection: 'column'
    }
}));
export default function CheckboxComponent(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, caption, value, readOnly, testId, required, disabled, status, helperText, validatemessage, displayMode, hideLabel, trueLabel, falseLabel, selectionMode, datasource, selectionKey, selectionList, primaryField, referenceList, readonlyContextList: selectedvalues } = props;
    const classes = useStyles();
    const helperTextToDisplay = validatemessage || helperText;
    const thePConn = getPConnect();
    const actionsApi = thePConn.getActionsApi();
    const propName = thePConn.getStateProps().value;
    const [checked, setChecked] = useState(false);
    useEffect(() => {
        // This update theSelectedButton which will update the UI to show the selected button correctly
        setChecked(value);
    }, [value]);
    useEffect(() => {
        if (referenceList?.length > 0) {
            thePConn.setReferenceList(selectionList);
            updateNewInstuctions(thePConn, selectionList);
        }
    }, [thePConn]);
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : caption, value: value ? trueLabel : falseLabel });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : caption, value: value ? trueLabel : falseLabel, variant: 'stacked' });
    }
    const handleChange = event => {
        handleEvent(actionsApi, 'changeNblur', propName, event.target.checked);
    };
    const handleBlur = event => {
        thePConn.getValidationApi().validate(event.target.checked);
    };
    const handleChangeMultiMode = (event, element) => {
        if (event.target.checked) {
            insertInstruction(thePConn, selectionList, selectionKey, primaryField, {
                id: element.key,
                primary: element.text ?? element.value
            });
        }
        else {
            deleteInstruction(thePConn, selectionList, selectionKey, {
                id: element.key,
                primary: element.text ?? element.value
            });
        }
        thePConn.clearErrorMessages({
            property: selectionList,
            category: '',
            context: ''
        });
    };
    let theCheckbox;
    const listOfCheckboxes = [];
    if (selectionMode === 'multi') {
        const listSourceItems = datasource?.source ?? [];
        const dataField = selectionKey?.split?.('.')[1];
        listSourceItems.forEach((element, index) => {
            listOfCheckboxes.push(_jsx(FormControlLabel, { control: _jsx(Checkbox, { checked: selectedvalues?.some?.(data => data[dataField] === element.key), onChange: event => handleChangeMultiMode(event, element), onBlur: () => {
                        thePConn.getValidationApi().validate(selectedvalues, selectionList);
                    }, "data-testid": `${testId}:${element.value}` }, index), label: element.text ?? element.value, labelPlacement: 'end', "data-test-id": testId }, index));
        });
        theCheckbox = _jsx("div", { className: classes.checkbox, children: listOfCheckboxes });
    }
    else {
        theCheckbox = (_jsx(FormControlLabel, { control: _jsx(Checkbox, { color: 'primary', checked: checked, onChange: !readOnly ? handleChange : undefined, onBlur: !readOnly ? handleBlur : undefined, value: value, disabled: disabled, readOnly: readOnly }), label: caption, labelPlacement: 'end', "data-test-id": testId }));
    }
    return (_jsxs(FormControl, { variant: 'standard', required: required, error: status === 'error', children: [!hideLabel && _jsx(FormLabel, { component: 'legend', children: label }), _jsx(FormGroup, { children: theCheckbox }), _jsx(FormHelperText, { children: helperTextToDisplay })] }));
}
//# sourceMappingURL=Checkbox.js.map