import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { InputAdornment, TextField } from '@mui/material';
import MailOutlineIcon from '@mui/icons-material/MailOutline';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
import handleEvent from '../../helpers/event-utils';
export default function Email(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const TextInput = getComponentFromMap('TextInput');
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, required, disabled, value = '', validatemessage, status, readOnly, testId, helperText, displayMode, hideLabel, placeholder } = props;
    const pConn = getPConnect();
    const actions = pConn.getActionsApi();
    const propName = pConn.getStateProps().value;
    const helperTextToDisplay = validatemessage || helperText;
    const [inputValue, setInputValue] = useState('');
    useEffect(() => {
        setInputValue(value);
    }, [value]);
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value, variant: 'stacked' });
    }
    if (readOnly) {
        return _jsx(TextInput, { ...props });
    }
    let testProp = {};
    testProp = {
        'data-test-id': testId
    };
    function handleChange(event) {
        // update internal value
        setInputValue(event?.target?.value);
    }
    function handleBlur() {
        handleEvent(actions, 'changeNblur', propName, inputValue);
    }
    return (_jsx(TextField, { fullWidth: true, variant: 'outlined', helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', required: required, disabled: disabled, onChange: handleChange, onBlur: !readOnly ? handleBlur : undefined, error: status === 'error', label: label, value: inputValue, type: 'email', InputProps: {
            startAdornment: (_jsx(InputAdornment, { position: 'start', children: _jsx(MailOutlineIcon, {}) })),
            inputProps: { ...testProp }
        } }));
}
//# sourceMappingURL=Email.js.map