import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { TextField } from '@mui/material';
import handleEvent from '../../helpers/event-utils';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
export default function Integer(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const TextInput = getComponentFromMap('TextInput');
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, required, disabled, value = '', validatemessage, status, readOnly, testId, helperText, displayMode, hideLabel, placeholder } = props;
    const pConn = getPConnect();
    const actions = pConn.getActionsApi();
    const propName = pConn.getStateProps().value;
    const helperTextToDisplay = validatemessage || helperText;
    const [inputValue, setInputValue] = useState('');
    useEffect(() => {
        setInputValue(value);
    }, [value]);
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value, variant: 'stacked' });
    }
    if (readOnly) {
        return _jsx(TextInput, { ...props });
    }
    let testProp = {};
    testProp = {
        'data-test-id': testId
    };
    function intOnChange(event) {
        // console.log(`Integer intOnChange inValue: ${event.target.value}`);
        // Disallow "." and "," (separators) since this is an integer field
        //  Mimics Pega Integer behavior (where separator characters are "eaten" if they're typed)
        const disallowedChars = ['.', ','];
        const theAttemptedValue = event.target.value;
        const lastChar = theAttemptedValue.slice(-1);
        if (disallowedChars.includes(lastChar)) {
            event.target.value = theAttemptedValue.slice(0, -1);
        }
        // Pass through to the Constellation change handler
        setInputValue(event.target.value);
    }
    function handleBlur() {
        handleEvent(actions, 'changeNblur', propName, inputValue);
    }
    return (_jsx(TextField, { fullWidth: true, variant: readOnly ? 'standard' : 'outlined', helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', required: required, disabled: disabled, onChange: intOnChange, onBlur: !readOnly ? handleBlur : undefined, error: status === 'error', label: label, value: inputValue, type: 'text', inputProps: { inputMode: 'numeric', pattern: '[0-9]*', ...testProp } }));
}
//# sourceMappingURL=Integer.js.map