import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { MuiTelInput } from 'mui-tel-input';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
import handleEvent from '../../helpers/event-utils';
export default function Phone(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, required, disabled, value = '', validatemessage, status, onChange, readOnly, testId, helperText, displayMode, hideLabel, placeholder } = props;
    const pConn = getPConnect();
    const actions = pConn.getActionsApi();
    const propName = pConn.getStateProps().value;
    const [inputValue, setInputValue] = useState(value);
    useEffect(() => setInputValue(value), [value]);
    const helperTextToDisplay = validatemessage || helperText;
    let testProp = {};
    testProp = {
        'data-test-id': testId
    };
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value, variant: 'stacked' });
    }
    if (readOnly) {
        const disableDropdown = true;
        return (_jsx("div", { children: _jsx(MuiTelInput, { fullWidth: true, helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', defaultCountry: 'US', required: required, disabled: disabled, onChange: onChange, error: status === 'error', label: label, value: value, InputProps: {
                    readOnly: true,
                    inputProps: { ...testProp }
                }, disableDropdown: disableDropdown }) }));
    }
    const handleChange = inputVal => {
        setInputValue(inputVal);
    };
    const handleBlur = event => {
        const phoneValue = event?.target?.value;
        let phoneNumber = phoneValue.split(' ').slice(1).join();
        phoneNumber = phoneNumber ? `+${phoneValue && phoneValue.replace(/\D+/g, '')}` : '';
        handleEvent(actions, 'changeNblur', propName, phoneNumber);
    };
    return (_jsx(MuiTelInput, { fullWidth: true, variant: 'outlined', helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', defaultCountry: 'US', required: required, disabled: disabled, onChange: handleChange, onBlur: !readOnly ? handleBlur : undefined, error: status === 'error', label: label, value: inputValue, InputProps: { ...testProp } }));
}
//# sourceMappingURL=Phone.js.map