import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState, useEffect } from 'react';
import { Radio, RadioGroup, FormControl, FormControlLabel, FormLabel, FormHelperText } from '@mui/material';
import Utils from '../../helpers/utils';
import handleEvent from '../../helpers/event-utils';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
export default function RadioButtons(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, value = '', readOnly, validatemessage, helperText, status, required, inline, displayMode, hideLabel, fieldMetadata } = props;
    const [theSelectedButton, setSelectedButton] = useState(value);
    const thePConn = getPConnect();
    const theConfigProps = thePConn.getConfigProps();
    const actionsApi = thePConn.getActionsApi();
    const propName = thePConn.getStateProps().value;
    const helperTextToDisplay = validatemessage || helperText;
    const className = thePConn.getCaseInfo().getClassName();
    let configProperty = thePConn.getRawMetadata()?.config?.value || '';
    configProperty = configProperty.startsWith('@P') ? configProperty.substring(3) : configProperty;
    configProperty = configProperty.startsWith('.') ? configProperty.substring(1) : configProperty;
    const metaData = Array.isArray(fieldMetadata) ? fieldMetadata.filter(field => field?.classID === className)[0] : fieldMetadata;
    let displayName = metaData?.datasource?.propertyForDisplayText;
    displayName = displayName?.slice(displayName.lastIndexOf('.') + 1);
    const localeContext = metaData?.datasource?.tableType === 'DataPage' ? 'datapage' : 'associated';
    const localeClass = localeContext === 'datapage' ? '@baseclass' : className;
    const localeName = localeContext === 'datapage' ? metaData?.datasource?.name : configProperty;
    const localePath = localeContext === 'datapage' ? displayName : localeName;
    // theOptions will be an array of JSON objects that are literally key/value pairs.
    //  Ex: [ {key: "Basic", value: "Basic"} ]
    const theOptions = Utils.getOptionList(theConfigProps, thePConn.getDataObject(''));
    useEffect(() => {
        // This update theSelectedButton which will update the UI to show the selected button correctly
        setSelectedButton(value);
    }, [value]);
    if (displayMode === 'DISPLAY_ONLY') {
        return (_jsx(FieldValueList, { name: hideLabel ? '' : label, 
            // @ts-ignore - Property 'getLocaleRuleNameFromKeys' is private and only accessible within class 'C11nEnv'
            value: thePConn.getLocalizedValue(value, localePath, thePConn.getLocaleRuleNameFromKeys(localeClass, localeContext, localeName)) }));
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return (_jsx(FieldValueList, { name: hideLabel ? '' : label, 
            // @ts-ignore - Property 'getLocaleRuleNameFromKeys' is private and only accessible within class 'C11nEnv'
            value: thePConn.getLocalizedValue(value, localePath, thePConn.getLocaleRuleNameFromKeys(localeClass, localeContext, localeName)), variant: 'stacked' }));
    }
    const handleChange = event => {
        handleEvent(actionsApi, 'changeNblur', propName, event.target.value);
    };
    const handleBlur = event => {
        thePConn.getValidationApi().validate(event.target.value, ''); // 2nd arg empty string until typedef marked correctly as optional
    };
    return (_jsxs(FormControl, { variant: 'standard', error: status === 'error', required: required, children: [_jsx(FormLabel, { component: 'legend', children: label }), _jsx(RadioGroup, { value: theSelectedButton, onChange: handleChange, onBlur: !readOnly ? handleBlur : undefined, row: inline, children: theOptions.map(theOption => {
                    return (_jsx(FormControlLabel, { value: theOption.key, label: thePConn.getLocalizedValue(theOption.value, localePath, 
                        // @ts-ignore - Property 'getLocaleRuleNameFromKeys' is private and only accessible within class 'C11nEnv'
                        thePConn.getLocaleRuleNameFromKeys(localeClass, localeContext, localeName)), control: _jsx(Radio, { color: 'primary', disabled: readOnly }, theOption.key) }, theOption.key));
                }) }), _jsx(FormHelperText, { children: helperTextToDisplay })] }));
}
//# sourceMappingURL=RadioButtons.js.map