import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import Typography from '@mui/material/Typography';
import Grid from '@mui/material/Grid';
import makeStyles from '@mui/styles/makeStyles';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
/* although this is called the SemanticLink component, we are not yet displaying as a
SemanticLink in SDK and only showing the value as a read only text field. */
const useStyles = makeStyles(theme => ({
    root: {
        paddingRight: theme.spacing(1),
        paddingLeft: theme.spacing(1),
        paddingTop: theme.spacing(1),
        paddingBottom: theme.spacing(1),
        marginRight: theme.spacing(1),
        marginLeft: theme.spacing(1),
        marginTop: theme.spacing(1),
        marginBottom: theme.spacing(1)
    },
    fieldMargin: {
        paddingRight: theme.spacing(1),
        paddingLeft: theme.spacing(1),
        paddingTop: theme.spacing(1),
        paddingBottom: theme.spacing(1),
        marginRight: theme.spacing(1),
        marginLeft: theme.spacing(1),
        marginTop: theme.spacing(1),
        marginBottom: theme.spacing(1)
    },
    fieldLabel: {
        fontWeight: 400,
        color: theme.palette.text.secondary
    },
    fieldValue: {
        fontWeight: 400,
        color: theme.palette.text.primary
    }
}));
export default function SemanticLink(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { text, displayMode, label, hideLabel } = props;
    const classes = useStyles();
    if (displayMode === 'DISPLAY_ONLY' || (!displayMode && label !== undefined)) {
        const value = text || '---';
        return (_jsxs(Grid, { container: true, spacing: 1, style: { padding: '4px 0px' }, id: 'semantic-link-grid', children: [_jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'body2', component: 'span', className: `${classes.fieldLabel} ${classes.fieldMargin}`, children: label }) }), _jsx(Grid, { item: true, xs: 6, children: _jsx(Typography, { variant: 'body2', component: 'span', className: classes.fieldValue, children: value }) })] }));
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: text, variant: 'stacked' });
    }
}
//# sourceMappingURL=SemanticLink.js.map