import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { TextField } from '@mui/material';
import handleEvent from '../../helpers/event-utils';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
export default function TextArea(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const { getPConnect, label, required, disabled, value = '', validatemessage, status, readOnly, testId, fieldMetadata, helperText, displayMode, hideLabel, placeholder } = props;
    const helperTextToDisplay = validatemessage || helperText;
    const pConn = getPConnect();
    const actions = pConn.getActionsApi();
    const propName = pConn.getStateProps().value;
    const maxLength = fieldMetadata?.maxLength;
    const [inputValue, setInputValue] = useState('');
    let readOnlyProp = {};
    useEffect(() => {
        setInputValue(value);
    }, [value]);
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value, variant: 'stacked' });
    }
    if (readOnly) {
        // Not just emitting a read only Textfield like some other components do
        //  since we want to preserve the minRows, maxRows info.
        readOnlyProp = { readOnly: true };
    }
    let testProp = {};
    testProp = {
        'data-test-id': testId
    };
    function handleChange(event) {
        // update internal value
        setInputValue(event?.target?.value);
    }
    function handleBlur() {
        handleEvent(actions, 'changeNblur', propName, inputValue);
    }
    return (_jsx(TextField, { multiline: true, minRows: 5, maxRows: 5, fullWidth: true, variant: readOnly ? 'standard' : 'outlined', helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', required: required, disabled: disabled, onChange: handleChange, onBlur: !readOnly ? handleBlur : undefined, error: status === 'error', label: label, value: inputValue, InputProps: { ...readOnlyProp, inputProps: { maxLength, ...testProp } } }));
}
//# sourceMappingURL=TextArea.js.map