import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { TextField } from '@mui/material';
import handleEvent from '../../helpers/event-utils';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
// NOTE: that we had to change the name from URL to URLComponent
//  Otherwise, we were getting all kinds of weird errors when we
//  referred to URL as a component.
export default function URLComponent(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const FieldValueList = getComponentFromMap('FieldValueList');
    const TextInput = getComponentFromMap('TextInput');
    const { getPConnect, label, required, disabled, value = '', validatemessage, status, readOnly, testId, helperText, displayMode, hideLabel, placeholder } = props;
    const helperTextToDisplay = validatemessage || helperText;
    const [inputValue, setInputValue] = useState('');
    const pConn = getPConnect();
    const actions = pConn.getActionsApi();
    const propName = pConn.getStateProps().value;
    useEffect(() => {
        setInputValue(value);
    }, [value]);
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: value, variant: 'stacked' });
    }
    if (readOnly) {
        return _jsx(TextInput, { ...props });
    }
    let testProp = {};
    testProp = {
        'data-test-id': testId
    };
    const handleChange = event => {
        setInputValue(event?.target?.value);
    };
    function handleBlur() {
        handleEvent(actions, 'changeNblur', propName, inputValue);
    }
    return (_jsx(TextField, { type: 'url', fullWidth: true, variant: 'outlined', helperText: helperTextToDisplay, placeholder: placeholder ?? '', size: 'small', required: required, disabled: disabled, onChange: handleChange, onBlur: !readOnly ? handleBlur : undefined, error: status === 'error', label: label, value: inputValue, InputProps: { inputProps: { ...testProp } } }));
}
//# sourceMappingURL=URL.js.map