import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { memo, useEffect, useState } from 'react';
import { Typography } from '@mui/material';
import { getComponentFromMap } from '../../../bridge/helpers/sdk_component_map';
import FieldValueList from '../../designSystemExtension/FieldValueList';
import { getUserId, isUserNameAvailable } from './UserReferenceUtils';
const DROPDOWN_LIST = 'Drop-down list';
const SEARCH_BOX = 'Search box';
const UserReference = (props) => {
    // Get emitted components from map (so we can get any override that may exist)
    const AutoComplete = getComponentFromMap('AutoComplete');
    const Dropdown = getComponentFromMap('Dropdown');
    const { label = '', displayAs = '', displayMode = '', getPConnect, value = '', testId = '', helperText = '', validatemessage = '', placeholder = '', showAsFormattedText = false, additionalProps = {}, hideLabel = false, readOnly = false, required = false, disabled = false, onChange, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    variant = 'inline' } = props;
    const [dropDownDataSource, setDropDownDataSource] = useState([]);
    const [userName, setUserName] = useState('');
    const OPERATORS_DP = PCore.getEnvironmentInfo().getDefaultOperatorDP();
    const userId = getUserId(value);
    useEffect(() => {
        if (userId && readOnly && showAsFormattedText) {
            if (isUserNameAvailable(value)) {
                setUserName(value.userName);
            }
            else {
                // if same user ref field is referred in view as editable & readonly formatted text
                // referenced users won't be available, so get user details from dx api
                const { getOperatorDetails } = PCore.getUserApi();
                getOperatorDetails(userId).then((res) => {
                    if (res.data && res.data.pyOperatorInfo && res.data.pyOperatorInfo.pyUserName) {
                        setUserName(res.data.pyOperatorInfo.pyUserName);
                    }
                });
            }
        }
        else if (displayAs === DROPDOWN_LIST) {
            const queryPayload = {
                dataViewName: OPERATORS_DP
            };
            PCore.getRestClient()
                // @ts-ignore - Argument of type '{ queryPayload: { dataViewName: string; }; }' is not assignable to parameter of type 'RestApiOptionsObject'
                // @ts-ignore - Expected 3 arguments, but got 2
                .invokeRestApi('getListData', { queryPayload })
                .then((res) => {
                const ddDataSource = res.data.data.map(listItem => ({
                    key: listItem.pyUserIdentifier,
                    value: listItem.pyUserName
                }));
                setDropDownDataSource(ddDataSource);
            })
                .catch(err => {
                // eslint-disable-next-line no-console
                console.error(err);
            });
        }
    }, [displayAs, readOnly, showAsFormattedText, value]);
    let userReferenceComponent = null;
    if (displayMode === 'DISPLAY_ONLY') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: userName || '' });
    }
    if (displayMode === 'STACKED_LARGE_VAL') {
        return _jsx(FieldValueList, { name: hideLabel ? '' : label, value: userName || '', variant: 'stacked' });
    }
    if (readOnly && showAsFormattedText) {
        if (userId) {
            userReferenceComponent = (_jsx(_Fragment, { children: _jsxs("div", { children: [_jsx(Typography, { variant: 'caption', children: label }), _jsx(Typography, { variant: 'body1', children: userName })] }) }));
        }
    }
    else {
        if (displayAs === SEARCH_BOX) {
            const columns = [
                {
                    value: 'pyUserName',
                    display: 'true',
                    useForSearch: true,
                    primary: 'true'
                },
                {
                    value: 'pyUserIdentifier',
                    setProperty: 'Associated property',
                    key: 'true',
                    display: 'true',
                    secondary: 'true',
                    useForSearch: 'true'
                }
            ];
            userReferenceComponent = (_jsx(AutoComplete, { additionalProps: additionalProps, label: label, getPConnect: getPConnect, datasource: OPERATORS_DP, listType: 'datapage', columns: columns, testId: testId, placeholder: placeholder, readOnly: readOnly, disabled: disabled, required: required, helperText: helperText, validatemessage: validatemessage, value: userId, hideLabel: hideLabel, onChange: onChange }));
        }
        if (displayAs === DROPDOWN_LIST) {
            userReferenceComponent = (_jsx(Dropdown, { additionalProps: additionalProps, datasource: dropDownDataSource, listType: 'associated', getPConnect: getPConnect, label: label, value: userId, testId: testId, placeholder: placeholder, readOnly: readOnly, disabled: disabled, required: required, helperText: helperText, validatemessage: validatemessage, hideLabel: hideLabel, onChange: onChange }));
        }
    }
    return userReferenceComponent;
};
// as objects are there in props, shallow comparision fails & re-rendering of comp happens even with
// same key value pairs in obj. hence using custom comparison function on when to re-render
const comparisonFn = (prevProps, nextProps) => {
    return (getUserId(prevProps.value) === getUserId(nextProps.value) &&
        prevProps.validatemessage === nextProps.validatemessage &&
        prevProps.required === nextProps.required &&
        prevProps.disabled === nextProps.disabled &&
        prevProps.readOnly === nextProps.readOnly);
};
export default memo(UserReference, comparisonFn);
//# sourceMappingURL=UserReference.js.map