import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/* eslint-disable @typescript-eslint/no-shadow */
/* eslint-disable operator-assignment */
import { forwardRef, useEffect, useRef, useState } from 'react';
import { TextField } from '@mui/material';
import { v4 as uuidv4 } from 'uuid';
import { debounce } from 'throttle-debounce';
import DatePicker from 'react-datepicker';
import { createFilter, combineFilters, getFormattedDate, getFilterExpression } from './filterUtils';
import 'react-datepicker/dist/react-datepicker.css';
export default function DashboardFilter(props) {
    const { children = [], name, filterProp, type = '', metadata = null, getPConnect } = props;
    const { current: filterId } = useRef(uuidv4());
    const [startDate, setStartDate] = useState(null);
    const [endDate, setEndDate] = useState(null);
    useEffect(() => {
        PCore.getPubSubUtils().subscribe(PCore.getConstants().PUB_SUB_EVENTS.EVENT_DASHBOARD_FILTER_CLEAR_ALL, () => {
            if (type === 'Dropdown') {
                getPConnect().getActionsApi().updateFieldValue(filterProp, '');
            }
            else if (type === 'RadioButtons') {
                const reference = getPConnect().getFullReference() + filterProp;
                const radList = document.getElementsByName(reference);
                for (let i = 0; i < radList.length; i = i + 1) {
                    if (radList[i].value === '') {
                        radList[i].checked = true;
                    }
                    else {
                        radList[i].checked = false;
                    }
                }
            }
            else {
                getPConnect().getActionsApi().updateFieldValue(filterProp, undefined);
                if (type === 'DateTime') {
                    setStartDate(null);
                    setEndDate(null);
                }
            }
        }, filterId, false, getPConnect().getContextName());
        return function cleanup() {
            PCore.getPubSubUtils().unsubscribe(PCore.getConstants().PUB_SUB_EVENTS.EVENT_DASHBOARD_FILTER_CLEAR_ALL, filterId, getPConnect().getContextName());
        };
    });
    const fireFilterChange = filterValue => {
        const filterData = {
            filterId,
            filterExpression: getFilterExpression(filterValue, name, metadata)
        };
        PCore.getPubSubUtils().publish(PCore.getConstants().PUB_SUB_EVENTS.EVENT_DASHBOARD_FILTER_CHANGE, filterData);
    };
    const fireFilterChangeDebounced = debounce(500, fireFilterChange);
    const dateRangeChangeHandler = value => {
        const { start, end } = value;
        let startDate = getFormattedDate(start);
        let endDate = getFormattedDate(end);
        if (startDate && endDate) {
            startDate = `${startDate}T00:00:00`;
            endDate = `${endDate}T00:00:00`;
            const startFilter = createFilter(startDate, name, 'GT');
            const endFilter = createFilter(endDate, name, 'LT');
            const filterData = {
                filterId,
                filterExpression: combineFilters([startFilter, endFilter], null)
            };
            PCore.getPubSubUtils().publish(PCore.getConstants().PUB_SUB_EVENTS.EVENT_DASHBOARD_FILTER_CHANGE, filterData);
        }
    };
    const renderAutoComplete = () => {
        metadata.config.onRecordChange = e => {
            fireFilterChange(e.id);
        };
        return getPConnect().createComponent(metadata, '', 0, {}); // 2nd, 3rd, and 4th args empty string/object/null until typedef marked correctly as optional);
    };
    const onChange = dates => {
        const [start, end] = dates;
        setStartDate(start);
        setEndDate(end);
        dateRangeChangeHandler({ start, end });
    };
    const label = metadata.config.label.substring(3);
    // eslint-disable-next-line react/no-unstable-nested-components
    const CustomDateInput = forwardRef(({ value, onClick }, ref) => (_jsx(TextField, { label: label, variant: 'outlined', fullWidth: true, value: value, size: 'small', onClick: onClick, ref: ref, children: value })));
    return (_jsxs(_Fragment, { children: [type === 'DateTime' && (_jsx(DatePicker, { onChange: onChange, startDate: startDate, endDate: endDate, selectsRange: true, enableTabLoop: false, customInput: _jsx(CustomDateInput, {}) })), type === 'AutoComplete' && (_jsx("span", { onChange: event => {
                    if (event && event.target && !event.target.value) {
                        fireFilterChange('ALL');
                    }
                }, children: renderAutoComplete() })), children && (_jsx("span", { onChange: event => {
                    fireFilterChangeDebounced(event.target.value);
                }, children: children }))] }));
}
//# sourceMappingURL=DashboardFilter.js.map