import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { useTheme } from '@mui/material/styles';
import makeStyles from '@mui/styles/makeStyles';
import clsx from 'clsx';
import { Drawer, List, ListItem, ListItemIcon, ListItemText, ListItemSecondaryAction, Collapse, Divider, IconButton, Menu, MenuItem, Typography } from '@mui/material';
import PersonOutlineIcon from '@mui/icons-material/PersonOutlineOutlined';
import ChevronLeftIcon from '@mui/icons-material/ChevronLeft';
import ChevronRightIcon from '@mui/icons-material/ChevronRight';
import FlagOutlinedIcon from '@mui/icons-material/FlagOutlined';
import HomeOutlinedIcon from '@mui/icons-material/HomeOutlined';
import TabletAndroidOutlineIcon from '@mui/icons-material/TabletAndroidOutlined';
import AirportShuttleOutlinedIcon from '@mui/icons-material/AirportShuttleOutlined';
import EditOutlinedIcon from '@mui/icons-material/EditOutlined';
import ExpandLess from '@mui/icons-material/ExpandLess';
import ExpandMore from '@mui/icons-material/ExpandMore';
import AddIcon from '@mui/icons-material/Add';
import WorkOutlineIcon from '@mui/icons-material/WorkOutline';
import ClearOutlinedIcon from '@mui/icons-material/ClearOutlined';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import useMediaQuery from '@mui/material/useMediaQuery';
import { logout } from '@pega/auth/lib/sdk-auth-manager';
import { useNavBar } from '../../helpers/reactContextHelpers';
import { Utils } from '../../helpers/utils';
import './NavBar.css';
const iconMap = {
    'pi pi-headline': _jsx(HomeOutlinedIcon, { fontSize: 'large' }),
    'pi pi-flag-solid': _jsx(FlagOutlinedIcon, { fontSize: 'large' }),
    'pi pi-home-solid': _jsx(HomeOutlinedIcon, { fontSize: 'large' }),
    'pi pi-tablet': _jsx(TabletAndroidOutlineIcon, { fontSize: 'large' }),
    'pi pi-ambulance': _jsx(AirportShuttleOutlinedIcon, { fontSize: 'large' }),
    'pi pi-ink-solid': _jsx(EditOutlinedIcon, { fontSize: 'large' }),
    'pi pi-columns': _jsx(HomeOutlinedIcon, { fontSize: 'large' })
};
const drawerWidth = 300;
const useStyles = makeStyles(theme => ({
    drawerPaper: {
        position: 'relative',
        whiteSpace: 'nowrap',
        width: drawerWidth,
        transition: theme.transitions.create('width', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.enteringScreen
        }),
        height: '100vh'
    },
    drawerPaperClose: {
        overflowX: 'hidden',
        transition: theme.transitions.create('width', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.leavingScreen
        }),
        width: theme.spacing(7),
        [theme.breakpoints.up('md')]: {
            width: theme.spacing(9)
        },
        height: '100vh'
    },
    nested: {
        paddingLeft: theme.spacing(4)
    },
    appListItem: {
        backgroundColor: theme.palette.primary.light,
        color: theme.palette.getContrastText(theme.palette.primary.light)
    },
    appListLogo: {
        marginRight: theme.spacing(2),
        width: '3.6rem'
    },
    appListIcon: {
        color: theme.palette.getContrastText(theme.palette.primary.light)
    },
    appListDiv: {
        backgroundColor: theme.palette.primary.light,
        color: theme.palette.getContrastText(theme.palette.primary.light),
        paddingTop: theme.spacing(2),
        paddingBottom: theme.spacing(2),
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
    },
    applicationLabel: {
        whiteSpace: 'initial'
    }
}));
export default function NavBar(props) {
    const { pConn, pages = [], caseTypes = [] } = props;
    const classes = useStyles();
    const theme = useTheme();
    const isDesktop = useMediaQuery(theme.breakpoints.up('md'));
    const { open, setOpen } = useNavBar();
    const [navPages, setNavPages] = useState(JSON.parse(JSON.stringify(pages)));
    const [bShowCaseTypes, setBShowCaseTypes] = useState(true);
    const [bShowOperatorButtons, setBShowOperatorButtons] = useState(false);
    const [anchorEl, setAnchorEl] = useState(null);
    const localeUtils = PCore.getLocaleUtils();
    const localeReference = pConn.getValue('.pyLocaleReference');
    const localizedVal = PCore.getLocaleUtils().getLocaleValue;
    const localeCategory = 'AppShell';
    const portalLogoImage = Utils.getIconPath(Utils.getSDKStaticConentUrl()).concat('pzpega-logo-mark.svg');
    const portalOperator = PCore.getEnvironmentInfo().getOperatorName();
    const portalApp = PCore.getEnvironmentInfo().getApplicationLabel();
    useEffect(() => {
        setNavPages(JSON.parse(JSON.stringify(pages)));
    }, [pages]);
    function navPanelButtonClick(oPageData) {
        const { pyClassName, pyRuleName } = oPageData;
        pConn
            .getActionsApi()
            .showPage(pyRuleName, pyClassName)
            .then(() => {
            // eslint-disable-next-line no-console
            console.log(`${localizedVal('showPage completed', localeCategory)}`);
        });
    }
    function navPanelCreateCaseType(sCaseType, sFlowType) {
        setOpen(false);
        const actionInfo = {
            containerName: 'primary',
            flowType: sFlowType || 'pyStartCase'
        };
        pConn
            .getActionsApi()
            .createWork(sCaseType, actionInfo)
            .then(() => {
            // eslint-disable-next-line no-console
            console.log(`${localizedVal('createWork completed', localeCategory)}`);
        });
    }
    // Toggle showing the Operator buttons
    function navPanelOperatorButtonClick(evt) {
        setBShowOperatorButtons(!bShowOperatorButtons);
        if (!bShowOperatorButtons)
            setAnchorEl(evt.currentTarget);
        else
            setAnchorEl(null);
    }
    const handleDrawerOpen = () => {
        setOpen(!open);
    };
    const handleCaseItemClick = () => {
        if (!open) {
            setOpen(true);
            setBShowCaseTypes(true);
        }
        else
            setBShowCaseTypes(!bShowCaseTypes);
    };
    useEffect(() => {
        if (!isDesktop)
            setOpen(false);
        else
            setOpen(true);
    }, [isDesktop]);
    return (_jsxs(Drawer, { variant: 'permanent', classes: {
            paper: clsx(classes.drawerPaper, !open && classes.drawerPaperClose)
        }, open: open && isDesktop, children: [open ? (_jsx(List, { className: classes.appListItem, children: _jsxs(ListItem, { onClick: handleDrawerOpen, children: [_jsx(ListItemIcon, { children: _jsx("img", { src: portalLogoImage, className: classes.appListLogo }) }), _jsx(ListItemText, { primary: _jsx(Typography, { variant: 'h6', className: classes.applicationLabel, children: portalApp }) }), _jsx(ListItemSecondaryAction, { children: _jsx(IconButton, { edge: 'end', onClick: handleDrawerOpen, size: 'large', children: _jsx(ChevronLeftIcon, { className: classes.appListIcon }) }) })] }) })) : (_jsx("div", { className: classes.appListDiv, onClick: handleDrawerOpen, children: _jsx(ChevronRightIcon, { className: classes.appListIcon, id: 'chevron-right-icon', fontSize: 'large' }) })), _jsx(List, { children: _jsxs(ListItem, { button: true, onClick: handleCaseItemClick, children: [_jsx(ListItemIcon, { children: bShowCaseTypes && open ? _jsx(ClearOutlinedIcon, { fontSize: 'large' }) : _jsx(AddIcon, { fontSize: 'large' }) }), _jsx(ListItemText, { primary: 'Create' }), bShowCaseTypes ? _jsx(ExpandLess, {}) : _jsx(ExpandMore, {})] }) }), _jsx(Collapse, { in: bShowCaseTypes && open, timeout: 'auto', unmountOnExit: true, className: 'scrollable', children: _jsx(List, { component: 'div', disablePadding: true, children: caseTypes.map(caseType => (_jsxs(ListItem, { button: true, className: classes.nested, onClick: () => navPanelCreateCaseType(caseType.pyClassName, caseType.pyFlowType), children: [_jsx(ListItemIcon, { children: _jsx(WorkOutlineIcon, { fontSize: 'large' }) }), _jsx(ListItemText, { primary: localeUtils.getLocaleValue(caseType.pyLabel, '', localeReference) })] }, caseType.pyLabel))) }) }), _jsx(List, { children: navPages.map(page => (_jsxs(ListItem, { button: true, onClick: () => navPanelButtonClick(page), children: [_jsx(ListItemIcon, { children: iconMap[page.pxPageViewIcon] }), _jsx(ListItemText, { primary: localeUtils.getLocaleValue(page.pyLabel, '', localeReference) })] }, page.pyLabel))) }), _jsx(Divider, {}), _jsx(List, { className: 'marginTopAuto', children: _jsxs(_Fragment, { children: [_jsxs(ListItem, { onClick: navPanelOperatorButtonClick, children: [_jsx(ListItemIcon, { id: 'person-icon', children: _jsx(PersonOutlineIcon, { fontSize: 'large' }) }), _jsx(ListItemText, { primary: portalOperator }), open && (_jsx(ListItemSecondaryAction, { children: _jsx(IconButton, { edge: 'end', onClick: navPanelOperatorButtonClick, size: 'large', children: _jsx(ChevronRightIcon, {}) }) }))] }), _jsx(Menu, { anchorEl: anchorEl, keepMounted: bShowOperatorButtons, open: bShowOperatorButtons, onClick: navPanelOperatorButtonClick, anchorOrigin: {
                                vertical: 'top',
                                horizontal: 'right'
                            }, transformOrigin: {
                                vertical: 'top',
                                horizontal: 'left'
                            }, children: _jsxs(MenuItem, { onClick: logout, children: [_jsx(ListItemIcon, { children: _jsx(ArrowBackIcon, { fontSize: 'large' }) }), _jsx(Typography, { variant: 'inherit', children: localizedVal('Log off', localeCategory) })] }) })] }) })] }));
}
//# sourceMappingURL=NavBar.js.map