import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import TextField from '@mui/material/TextField';
import { Utils } from '../../../helpers/utils';
import download from 'downloadjs';
// import SummaryList from '../../SummaryList';
// import ActionButtonsForFileUtil from '../ActionButtonsForFileUtil';
import './FileUtility.css';
import { IconButton, Menu, MenuItem, Button, CircularProgress } from '@mui/material';
import MoreVertIcon from '@mui/icons-material/MoreVert';
import { validateMaxSize } from '../../../helpers/attachmentHelpers';
import { getComponentFromMap } from '../../../../bridge/helpers/sdk_component_map';
export default function FileUtility(props) {
    // Get emitted components from map (so we can get any override that may exist)
    const SummaryList = getComponentFromMap('SummaryList');
    const ActionButtonsForFileUtil = getComponentFromMap('ActionButtonsForFileUtil');
    const { getPConnect } = props;
    const thePConn = getPConnect();
    const required = true;
    const listTemp = {
        data: [],
        count: 0
    };
    const [list, setList] = useState(listTemp);
    const headerSvgIcon$ = Utils.getImageSrc('paper-clip', Utils.getSDKStaticConentUrl());
    const closeSvgIcon = Utils.getImageSrc('times', Utils.getSDKStaticConentUrl());
    const configProps = thePConn.resolveConfigProps(thePConn.getConfigProps());
    const header = configProps.label;
    const fileTemp = {
        showfileModal: false,
        fileList: [],
        attachedFiles: [],
        fileMainButtons: [
            {
                actionID: 'attach',
                jsAction: 'attachFiles',
                name: thePConn.getLocalizedValue('Attach files', '', '')
            }
        ],
        fileSecondaryButtons: [
            {
                actionID: 'cancel',
                jsAction: 'cancel',
                name: thePConn.getLocalizedValue('Cancel', '', '')
            }
        ] // 2nd and 3rd args empty string until typedef marked correctly
    };
    const [fileData, setFileData] = useState(fileTemp);
    const linkTemp = {
        showLinkModal: false,
        linksList: [],
        attachedLinks: [],
        linkMainButtons: [
            {
                actionID: 'attach',
                jsAction: 'attachLinks',
                name: thePConn.getLocalizedValue('Attach links', '', '')
            }
        ],
        linkSecondaryButtons: [
            {
                actionID: 'cancel',
                jsAction: 'cancel',
                name: thePConn.getLocalizedValue('Cancel', '', '')
            }
        ] // 2nd and 3rd args empty string until typedef marked correctly
    };
    const [linkData, setLinkData] = useState(linkTemp);
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    const [link, setLink] = useState({ title: '', url: '', disable: true });
    const [inProgress, setProgress] = useState(false);
    const [showViewAllModal, setViewAll] = useState(false);
    const [vaItems, setFullAttachments] = useState([]);
    function addAttachments(attsFromResp = []) {
        attsFromResp = attsFromResp.map(respAtt => {
            const updatedAtt = {
                ...respAtt,
                meta: `${respAtt.category} . ${Utils.generateDateTime(respAtt.createTime, 'DateTime-Since')}, ${respAtt.createdBy}`
            };
            if (updatedAtt.type === 'FILE') {
                updatedAtt.nameWithExt = updatedAtt.fileName;
            }
            return updatedAtt;
        });
        return attsFromResp;
    }
    function getListUtilityItemProps({ att, cancelFile, downloadFile, deleteFile, removeFile }) {
        let actions;
        if (att.progress && att.progress !== 100) {
            actions = [
                {
                    id: `Cancel-${att.ID}`,
                    text: thePConn.getLocalizedValue('Cancel', '', ''),
                    icon: 'times',
                    onClick: cancelFile
                }
            ];
        }
        else if (att.links) {
            const isFile = att.type === 'FILE';
            const ID = att.ID.replace(/\s/gi, '');
            const actionsMap = new Map([
                [
                    'download',
                    {
                        id: `download-${ID}`,
                        text: isFile ? thePConn.getLocalizedValue('Download', '', '') : thePConn.getLocalizedValue('Open', '', ''),
                        icon: isFile ? 'download' : 'open',
                        onClick: downloadFile
                    }
                ],
                [
                    'delete',
                    {
                        id: `Delete-${ID}`,
                        text: thePConn.getLocalizedValue('Delete', '', ''),
                        icon: 'trash',
                        onClick: deleteFile
                    }
                ]
            ]);
            actions = [];
            actionsMap.forEach((action, actionKey) => {
                if (att.links[actionKey]) {
                    actions.push(action);
                }
            });
        }
        else if (att.error) {
            actions = [
                {
                    id: `Remove-${att.ID}`,
                    text: thePConn.getLocalizedValue('Remove', '', ''),
                    icon: 'trash',
                    onClick: removeFile
                }
            ];
        }
        return {
            id: att.ID,
            visual: {
                icon: Utils.getIconForAttachment(att),
                progress: att.progress === 100 ? undefined : att.progress
            },
            primary: {
                type: att.type,
                name: att.name,
                icon: 'open',
                click: downloadFile
            },
            secondary: {
                text: att.meta
            },
            actions
        };
    }
    function fileDownload(data, fileName, ext) {
        const file = ext ? `${fileName}.${ext}` : fileName;
        download(atob(data), file);
    }
    function downloadAttachedFile(att) {
        const attachUtils = PCore.getAttachmentUtils();
        const { ID, name, extension, type } = att;
        const context = thePConn.getContextName();
        attachUtils
            // @ts-ignore - 3rd parameter "responseEncoding" is optional
            .downloadAttachment(ID, context)
            .then((content) => {
            if (type === 'FILE') {
                fileDownload(content.data, name, extension);
            }
            else if (type === 'URL') {
                let { data } = content;
                if (!/^(http|https):\/\//.test(data)) {
                    data = `//${data}`;
                }
                window.open(content.data, '_blank');
            }
        })
            .catch();
    }
    function deleteAttachedFile(att) {
        const attachUtils = PCore.getAttachmentUtils();
        const { ID } = att;
        const context = thePConn.getContextName();
        attachUtils
            .deleteAttachment(ID, context)
            .then(() => {
            // eslint-disable-next-line @typescript-eslint/no-use-before-define
            getAttachments();
        })
            .catch();
    }
    const getAttachments = () => {
        const attachmentUtils = PCore.getAttachmentUtils();
        const caseID = thePConn.getValue(PCore.getConstants().CASE_INFO.CASE_INFO_ID, ''); // 2nd arg empty string until typedef marked correctly
        if (caseID && caseID !== '') {
            const attPromise = attachmentUtils.getCaseAttachments(caseID, thePConn.getContextName());
            attPromise.then((resp) => {
                const arFullListAttachments = addAttachments(resp);
                const attachmentsCount = arFullListAttachments.length;
                const arItems = arFullListAttachments.slice(0, 3).map(att => {
                    return getListUtilityItemProps({
                        att,
                        downloadFile: !att.progress ? () => downloadAttachedFile(att) : null,
                        cancelFile: null,
                        deleteFile: !att.progress ? () => deleteAttachedFile(att) : null,
                        removeFile: null
                    });
                });
                const viewAllarItems = arFullListAttachments.map(att => {
                    return getListUtilityItemProps({
                        att,
                        downloadFile: !att.progress ? () => downloadAttachedFile(att) : null,
                        cancelFile: null,
                        deleteFile: !att.progress ? () => deleteAttachedFile(att) : null,
                        removeFile: null
                    });
                });
                setProgress(false);
                setList(current => {
                    return { ...current, count: attachmentsCount, data: arItems };
                });
                setFullAttachments(viewAllarItems);
            });
        }
    };
    useEffect(() => {
        getAttachments();
    }, []);
    useEffect(() => {
        PCore.getPubSubUtils().subscribe(PCore.getEvents().getCaseEvent().CASE_ATTACHMENTS_UPDATED_FROM_CASEVIEW, getAttachments, 'caseAttachmentsUpdateFromCaseview');
        return () => {
            PCore.getPubSubUtils().unsubscribe(PCore.getEvents().getCaseEvent().CASE_ATTACHMENTS_UPDATED_FROM_CASEVIEW, 'caseAttachmentsUpdateFromCaseview');
        };
    }, []);
    function setNewFiles(arFiles) {
        let index = 0;
        for (const file of arFiles) {
            if (!validateMaxSize(file, '5')) {
                file.error = true;
                file.meta = 'File is too big. Max allowed size is 5MB.';
            }
            file.mimeType = file.type;
            file.icon = Utils.getIconFromFileType(file.type);
            file.ID = `${new Date().getTime()}I${index}`;
            index += 1;
        }
        return arFiles;
    }
    function getFiles(arFiles) {
        return setNewFiles(arFiles);
    }
    function uploadMyFiles(event) {
        // alert($event.target.files[0]); // outputs the first file
        const arFiles = getFiles(event.target.files);
        // convert FileList to an array
        const myFiles = Array.from(arFiles);
        const arFileList$ = myFiles.map((att) => {
            return getListUtilityItemProps({
                att,
                downloadFile: !att.progress ? () => downloadAttachedFile(att) : null,
                cancelFile: null,
                deleteFile: !att.progress ? () => deleteAttachedFile(att) : null,
                removeFile: null
            });
        });
        setFileData(current => {
            return { ...current, fileList: arFileList$, attachedFiles: myFiles };
        });
    }
    const handleClick = event => {
        setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
        setAnchorEl(null);
    };
    function onAddFilesClick() {
        setFileData(current => {
            return { ...current, showfileModal: true };
        });
        setAnchorEl(null);
    }
    function removeFileFromList(item) {
        let attachedFiles = fileData.attachedFiles;
        let fileList = fileData.fileList;
        if (item !== null) {
            attachedFiles = attachedFiles.filter(ele => ele.ID !== item.id);
            fileList = fileList.filter(ele => ele.id !== item.id);
            setFileData(current => {
                return { ...current, fileList, attachedFiles };
            });
        }
    }
    function closeFilePopup() {
        setFileData(current => {
            return { ...current, showfileModal: false };
        });
    }
    function onAttachFiles() {
        const attachmentUtils = PCore.getAttachmentUtils();
        const caseID = thePConn.getValue(PCore.getConstants().CASE_INFO.CASE_INFO_ID, ''); // 2nd arg empty string until typedef marked correctly
        const onUploadProgress = () => { };
        const errorHandler = () => { };
        closeFilePopup();
        if (fileData.attachedFiles && fileData.attachedFiles.length > 0) {
            setProgress(true);
        }
        Promise.allSettled(fileData.attachedFiles.map(file => attachmentUtils.uploadAttachment(file, onUploadProgress, errorHandler, thePConn.getContextName())))
            .then((fileResponses) => {
            const uploadedFiles = [];
            fileResponses.forEach(fileResponse => {
                if (fileResponse.status === 'fulfilled') {
                    uploadedFiles.push(fileResponse.value);
                }
            });
            if (uploadedFiles.length > 0) {
                attachmentUtils.linkAttachmentsToCase(caseID, uploadedFiles, 'File', thePConn.getContextName())
                    .then(() => {
                    setFileData(current => {
                        return { ...current, fileList: [], attachedFiles: [] };
                    });
                    getAttachments();
                })
                    .catch();
            }
        })
            .catch();
    }
    function onAddLinksClick() {
        setLinkData(current => {
            return { ...current, showLinkModal: true };
        });
        setAnchorEl(null);
    }
    function closeAddLinksPopup() {
        setLinkData(current => {
            return { ...current, showLinkModal: false };
        });
    }
    const fieldlinkOnChange = event => {
        const title = event.target.value;
        setLink(current => {
            const updatedData = { ...current, title };
            updatedData.disable = !(updatedData.title && updatedData.url);
            return updatedData;
        });
    };
    function fieldurlOnChange(event) {
        const url = event.target.value;
        setLink(current => {
            const updatedData = { ...current, url };
            updatedData.disable = !(updatedData.title && updatedData.url);
            return updatedData;
        });
    }
    function addLink() {
        // copy list locally
        const localList = linkData.linksList.slice();
        const url = link.url;
        if (!/^(http|https):\/\//.test(link.url)) {
            link.url = `http://${link.url}`;
        }
        // list for display
        let oLink = {};
        oLink.icon = 'chain';
        oLink.ID = `${new Date().getTime()}`;
        oLink = getListUtilityItemProps({
            att: oLink,
            downloadFile: null,
            cancelFile: null,
            deleteFile: null,
            removeFile: null
        });
        oLink.type = 'URL';
        oLink.primary.type = oLink.type;
        oLink.visual.icon = 'chain';
        oLink.primary.name = link.title;
        oLink.primary.icon = 'open';
        oLink.secondary.text = url;
        localList.push(oLink);
        // list for actually attachments
        const attachedListTemp = linkData.attachedLinks.slice();
        const attachedLink = {};
        attachedLink.id = oLink.id;
        attachedLink.linkTitle = link.title;
        attachedLink.type = oLink.type;
        attachedLink.url = url;
        attachedListTemp.push(attachedLink);
        setLinkData(current => {
            return {
                ...current,
                linksList: localList,
                attachedLinks: attachedListTemp
            };
        });
        // clear values
        setLink({ title: '', url: '', disable: true });
    }
    function removeLinksFromList(item) {
        let attachedLinks = linkData.attachedLinks;
        let linksList = linkData.linksList;
        if (item !== null) {
            attachedLinks = attachedLinks.filter(ele => ele.id !== item.id);
            linksList = linksList.filter(ele => ele.id !== item.id);
            setLinkData(current => {
                return { ...current, linksList, attachedLinks };
            });
        }
    }
    function onAttachLinks() {
        const attachmentUtils = PCore.getAttachmentUtils();
        const caseID = thePConn.getValue(PCore.getConstants().CASE_INFO.CASE_INFO_ID, ''); // 2nd arg empty string until typedef marked correctly
        const links = linkData.attachedLinks;
        closeAddLinksPopup();
        const linksToAttach = links.map((item) => ({
            type: 'URL',
            category: 'URL',
            url: item.url,
            name: item.linkTitle
        }));
        if (linksToAttach && linksToAttach.length > 0) {
            setProgress(true);
            attachmentUtils.linkAttachmentsToCase(caseID, linksToAttach, 'URL', thePConn.getContextName())
                .then(() => {
                setLinkData(current => {
                    return { ...current, linksList: [], attachedLinks: [] };
                });
                getAttachments();
            })
                .catch(() => setProgress(false));
        }
    }
    return (_jsxs("div", { className: 'psdk-utility', id: 'file-utility', children: [inProgress && (_jsx("div", { className: 'progress-div', children: _jsx(CircularProgress, {}) })), _jsxs("div", { className: 'psdk-header', children: [_jsx("img", { className: 'psdk-file-utility-card-svg-icon', src: headerSvgIcon$ }), _jsx("div", { className: 'header-text', children: header }), _jsx("div", { className: 'psdk-utility-count', id: 'attachments-count', children: list.count }), _jsx("div", { style: { flexGrow: 1 } }), _jsxs("div", { children: [_jsx(IconButton, { id: 'long-button', "aria-controls": open ? 'simple-menu' : undefined, "aria-expanded": open ? 'true' : undefined, "aria-haspopup": 'true', onClick: handleClick, size: 'large', children: _jsx(MoreVertIcon, {}) }), _jsxs(Menu, { style: { marginTop: '3rem' }, id: 'simple-menu', anchorEl: anchorEl, keepMounted: true, open: Boolean(anchorEl), onClose: handleClose, children: [_jsx(MenuItem, { style: { fontSize: '14px' }, onClick: onAddFilesClick, children: thePConn.getLocalizedValue('Add files', '', '') }), ' ', _jsx(MenuItem, { style: { fontSize: '14px' }, onClick: onAddLinksClick, children: thePConn.getLocalizedValue('Add links', '', '') }), ' '] })] })] }), list.data.length > 0 && (_jsx("div", { style: { marginTop: '1rem' }, children: _jsx(SummaryList, { "arItems$": list.data }) })), list.count > 3 && (_jsx("div", { className: 'psdk-utility-view-all', children: _jsx(Button, { style: { textTransform: 'none' }, color: 'primary', onClick: () => setViewAll(true), children: "View all" }) })), fileData.showfileModal && (_jsx("div", { className: 'psdk-dialog-background', children: _jsxs("div", { className: 'psdk-modal-file-top', children: [_jsx("h3", { children: thePConn.getLocalizedValue('Add local files', '', '') }), _jsxs("div", { className: 'psdk-modal-body', children: [_jsx("div", { className: 'psdk-modal-file-selector', children: _jsxs("label", { htmlFor: 'upload-files', children: [_jsx("input", { style: { display: 'none' }, id: 'upload-files', name: 'upload-files', type: 'file', multiple: true, onChange: uploadMyFiles }), _jsx(Button, { variant: 'outlined', color: 'primary', component: 'span', children: thePConn.getLocalizedValue('Attach files', '', '') }), ' '] }) }), fileData.fileList.length > 0 && (_jsx("div", { style: { marginTop: '1rem' }, children: _jsx(SummaryList, { "menuIconOverride$": 'trash', "arItems$": fileData.fileList, "menuIconOverrideAction$": removeFileFromList }) })), fileData.fileList.length === 0 && _jsx("div", {}), _jsx(ActionButtonsForFileUtil, { arMainButtons: fileData.fileMainButtons, arSecondaryButtons: fileData.fileSecondaryButtons, primaryAction: onAttachFiles, secondaryAction: closeFilePopup })] })] }) })), linkData.showLinkModal && (_jsx("div", { className: 'psdk-dialog-background', children: _jsxs("div", { className: 'psdk-modal-file-top', children: [_jsx("h3", { children: thePConn.getLocalizedValue('Add links', '', '') }), " ", _jsxs("div", { className: 'psdk-modal-body', children: [_jsxs("div", { className: 'psdk-modal-links-row', children: [_jsxs("div", { className: 'psdk-links-two-column', children: [_jsx("div", { className: 'psdk-modal-link-data', children: _jsx(TextField, { fullWidth: true, variant: 'outlined', label: 'Link title', size: 'small', required: required, value: link.title, onChange: fieldlinkOnChange }) }), _jsx("div", { className: 'psdk-modal-link-data', children: _jsx(TextField, { fullWidth: true, variant: 'outlined', label: 'URL', size: 'small', required: required, value: link.url, onChange: fieldurlOnChange }) })] }), _jsxs("div", { className: 'psdk-modal-link-add', children: [_jsx(Button, { className: 'psdk-add-link-action', color: 'primary', variant: 'contained', component: 'span', onClick: addLink, disabled: link.disable, children: thePConn.getLocalizedValue('Add link', '', '') }), ' '] })] }), linkData.linksList.length > 0 && (_jsx("div", { style: { marginTop: '1rem' }, children: _jsx(SummaryList, { "menuIconOverride$": 'trash', "arItems$": linkData.linksList, "menuIconOverrideAction$": removeLinksFromList }) })), _jsx(ActionButtonsForFileUtil, { arMainButtons: linkData.linkMainButtons, arSecondaryButtons: linkData.linkSecondaryButtons, primaryAction: onAttachLinks, secondaryAction: closeAddLinksPopup })] })] }) })), showViewAllModal && (_jsx("div", { className: 'psdk-dialog-background', children: _jsxs("div", { className: 'psdk-modal-file-top', children: [_jsxs("div", { className: 'psdk-view-all-header', children: [_jsx("h3", { children: thePConn.getLocalizedValue('Attachments', '', '') }), " ", _jsx("button", { type: 'button', className: 'psdk-close-button', onClick: () => setViewAll(false), children: _jsx("img", { className: 'psdk-utility-card-actions-svg-icon', src: closeSvgIcon }) })] }), _jsx("div", { className: 'psdk-view-all-body', children: _jsx(SummaryList, { "arItems$": vaItems }) })] }) }))] }));
}
//# sourceMappingURL=FileUtility.js.map