import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/* eslint-disable @typescript-eslint/no-shadow */
import { useCallback, useEffect, useState } from 'react';
import { Box, Button, Card, CardContent, CardHeader, Avatar, Typography, Badge, List, ListItem, ListItemText, ListItemSecondaryAction } from '@mui/material';
import Snackbar from '@mui/material/Snackbar';
import IconButton from '@mui/material/IconButton';
import CloseIcon from '@mui/icons-material/Close';
import ArrowForwardIosOutlinedIcon from '@mui/icons-material/ArrowForwardIosOutlined';
import { useTheme } from '@mui/material/styles';
import makeStyles from '@mui/styles/makeStyles';
import useMediaQuery from '@mui/material/useMediaQuery';
import { Utils } from '../../helpers/utils';
import './ToDo.css';
const fetchMyWorkList = (datapage, fields, numberOfRecords, includeTotalCount, context) => {
    return PCore.getDataPageUtils()
        .getDataAsync(datapage, context, {}, {
        pageNumber: 1,
        pageSize: numberOfRecords
    }, {
        select: Object.keys(fields).map(key => ({ field: PCore.getAnnotationUtils().getPropertyName(fields[key]) }))
    }, {
        invalidateCache: true,
        additionalApiParams: {
            includeTotalCount
        }
    })
        .then(response => {
        return {
            ...response,
            data: (Array.isArray(response?.data) ? response.data : []).map(row => Object.keys(fields).reduce((obj, key) => {
                obj[key] = row[PCore.getAnnotationUtils().getPropertyName(fields[key])];
                return obj;
            }, {}))
        };
    });
};
const isChildCase = assignment => {
    return assignment.isChild;
};
function topThreeAssignments(assignmentsSource) {
    return Array.isArray(assignmentsSource) ? assignmentsSource.slice(0, 3) : [];
}
function getID(assignment) {
    if (assignment.value) {
        const refKey = assignment.value;
        return refKey.substring(refKey.lastIndexOf(' ') + 1);
    }
    const refKey = assignment.ID;
    const arKeys = refKey.split('!')[0].split(' ');
    return arKeys[2];
}
const useStyles = makeStyles(theme => ({
    root: {
        marginTop: theme.spacing(1),
        marginBottom: theme.spacing(1),
        paddingBottom: theme.spacing(1),
        borderLeft: '6px solid',
        borderLeftColor: theme.palette.primary.light
    },
    avatar: {
        backgroundColor: theme.palette.primary.light,
        color: theme.palette.getContrastText(theme.palette.primary.light)
    },
    todoWrapper: {
        borderLeft: '6px solid',
        borderLeftColor: theme.palette.primary.light,
        padding: theme.spacing(1),
        margin: theme.spacing(1)
    }
}));
export default function ToDo(props) {
    const { getPConnect, context, datasource = [], headerText = 'To do', showTodoList = true, myWorkList = {}, type = 'worklist', isConfirm = false } = props;
    const CONSTS = PCore.getConstants();
    const bLogging = true;
    const currentUser = PCore.getEnvironmentInfo().getOperatorName();
    const currentUserInitials = Utils.getInitials(currentUser);
    const assignmentsSource = datasource?.source || myWorkList?.source;
    const [bShowMore, setBShowMore] = useState(true);
    const [showSnackbar, setShowSnackbar] = useState(false);
    const [snackbarMessage, setSnackbarMessage] = useState('');
    // eslint-disable-next-line @typescript-eslint/no-use-before-define
    const [assignments, setAssignments] = useState(initAssignments());
    const thePConn = getPConnect();
    const classes = useStyles();
    const theme = useTheme();
    const isDesktop = useMediaQuery(theme.breakpoints.up('md'));
    const localizedVal = PCore.getLocaleUtils().getLocaleValue;
    const localeCategory = 'Todo';
    const showlessLocalizedValue = localizedVal('show_less', 'CosmosFields');
    const showMoreLocalizedValue = localizedVal('show_more', 'CosmosFields');
    const canPerform = assignments?.[0]?.canPerform === 'true' || assignments?.[0]?.canPerform === true;
    const [count, setCount] = useState(0);
    const { WORK_BASKET: { MY_WORK_LIST } } = PCore.getConstants();
    function initAssignments() {
        if (assignmentsSource) {
            return topThreeAssignments(assignmentsSource);
        }
        // turn off todolist
        return [];
    }
    const deferLoadWorklistItems = useCallback(responseData => {
        setCount(responseData.totalCount);
        setAssignments(responseData.data);
    }, [MY_WORK_LIST]);
    useEffect(() => {
        if (Object.keys(myWorkList).length && myWorkList.datapage) {
            fetchMyWorkList(myWorkList.datapage, getPConnect().getComponentConfig()?.myWorkList.fields, 3, true, context).then(responseData => {
                deferLoadWorklistItems(responseData);
            });
        }
    }, []);
    const getAssignmentId = assignment => {
        return type === CONSTS.TODO ? assignment.ID : assignment.id;
    };
    const getPriority = assignment => {
        return type === CONSTS.TODO ? assignment.urgency : assignment.priority;
    };
    const getAssignmentName = assignment => {
        return type === CONSTS.TODO ? assignment.name : assignment.stepName;
    };
    function showToast(message) {
        const theMessage = `Assignment: ${message}`;
        // eslint-disable-next-line no-console
        console.error(theMessage);
        setSnackbarMessage(message);
        setShowSnackbar(true);
    }
    function handleSnackbarClose(event, reason) {
        if (reason === 'clickaway') {
            return;
        }
        setShowSnackbar(false);
    }
    function _showMore() {
        setBShowMore(false);
        if (type === CONSTS.WORKLIST && count && count > assignments.length && !assignmentsSource) {
            fetchMyWorkList(myWorkList.datapage, getPConnect().getComponentConfig()?.myWorkList.fields, count, false, context).then(response => {
                setAssignments(response.data);
            });
        }
        else {
            setAssignments(assignmentsSource);
        }
    }
    function _showLess() {
        setBShowMore(true);
        setAssignments(assignments => assignments.slice(0, 3));
    }
    function clickGo(assignment) {
        const id = getAssignmentId(assignment);
        let { classname = '' } = assignment;
        const sTarget = thePConn.getContainerName();
        const sTargetContainerName = sTarget;
        const options = {
            containerName: sTargetContainerName,
            channelName: ''
        };
        if (classname === null || classname === '') {
            classname = thePConn.getCaseInfo().getClassName();
        }
        if (sTarget === 'workarea') {
            options.isActionFromToDoList = true;
            options.target = '';
            options.context = null;
            options.isChild = isChildCase(assignment);
        }
        else {
            options.isActionFromToDoList = false;
            options.target = sTarget;
        }
        thePConn
            .getActionsApi()
            .openAssignment(id, classname, options)
            .then(() => {
            if (bLogging) {
                // eslint-disable-next-line no-console
                console.log(`openAssignment completed`);
            }
        })
            .catch(() => {
            showToast(`Submit failed!`);
        });
    }
    const renderTaskId = (type, getPConnect, showTodoList, assignment) => {
        const displayID = getID(assignment);
        if ((showTodoList && type !== CONSTS.TODO) || assignment.isChild === true) {
            /* Supress link for todo inside flow step */
            return _jsx(Button, { size: 'small', color: 'primary', children: `${assignment.name} ${getID(assignment)}` });
        }
        return displayID;
    };
    const getListItemComponent = assignment => {
        if (isDesktop) {
            return (_jsxs(_Fragment, { children: [localizedVal('Task in', localeCategory), renderTaskId(type, getPConnect, showTodoList, assignment), type === CONSTS.WORKLIST && assignment.status ? `\u2022 ` : undefined, type === CONSTS.WORKLIST && assignment.status ? _jsx("span", { className: 'psdk-todo-assignment-status', children: assignment.status }) : undefined, ` \u2022  ${localizedVal('Urgency', localeCategory)}  ${getPriority(assignment)}`] }));
        }
        return (_jsxs(_Fragment, { children: [_jsx(Button, { size: 'small', color: 'primary', children: `${assignment.name} ${getID(assignment)}` }), ` \u2022 ${localizedVal('Urgency', localeCategory)}  ${getPriority(assignment)}`] }));
    };
    // eslint-disable-next-line no-nested-ternary
    const getCount = () => (assignmentsSource ? assignmentsSource.length : type === CONSTS.WORKLIST ? count : 0);
    const toDoContent = (_jsxs(_Fragment, { children: [showTodoList && (_jsx(CardHeader, { title: _jsx(Badge, { badgeContent: getCount(), overlap: 'rectangular', color: 'primary', children: _jsxs(Typography, { variant: 'h6', children: [headerText, "\u00A0\u00A0\u00A0"] }) }) })), _jsx(List, { children: assignments.map(assignment => (_jsxs("div", { className: 'psdk-todo-avatar-header', children: [_jsx(Avatar, { className: classes.avatar, style: { marginRight: '16px' }, children: currentUserInitials }), _jsxs("div", { style: { display: 'block' }, children: [_jsx(Typography, { variant: 'h6', children: assignment?.name }), `${localizedVal('Task in', localeCategory)} ${renderTaskId(type, getPConnect, showTodoList, assignment)} \u2022  ${localizedVal('Urgency', localeCategory)}  ${getPriority(assignment)}`] }), (!isConfirm || canPerform) && (_jsx("div", { style: { marginLeft: 'auto' }, children: _jsx(IconButton, { id: 'go-btn', onClick: () => clickGo(assignment), size: 'large', children: _jsx(ArrowForwardIosOutlinedIcon, {}) }) }))] }, getAssignmentId(assignment)))) })] }));
    return (_jsxs(_Fragment, { children: [type === CONSTS.WORKLIST && (_jsxs(Card, { className: classes.root, children: [showTodoList && (_jsx(CardHeader, { title: _jsx(Badge, { badgeContent: getCount(), overlap: 'rectangular', color: 'primary', children: _jsxs(Typography, { variant: 'h6', children: [headerText, "\u00A0\u00A0\u00A0"] }) }), avatar: _jsx(Avatar, { className: classes.avatar, children: currentUserInitials }) })), _jsx(CardContent, { children: _jsx(List, { children: assignments.map(assignment => (_jsxs(ListItem, { dense: true, divider: true, onClick: () => clickGo(assignment), children: [_jsx(ListItemText, { primary: getAssignmentName(assignment), secondary: getListItemComponent(assignment) }), _jsx(ListItemSecondaryAction, { children: _jsx(IconButton, { onClick: () => clickGo(assignment), size: 'large', children: _jsx(ArrowForwardIosOutlinedIcon, {}) }) })] }, getAssignmentId(assignment)))) }) })] })), type === CONSTS.TODO && !isConfirm && _jsx(Card, { className: classes.todoWrapper, children: toDoContent }), type === CONSTS.TODO && isConfirm && _jsx(_Fragment, { children: toDoContent }), getCount() > 3 && (_jsx(Box, { display: 'flex', justifyContent: 'center', children: bShowMore ? (_jsx(Button, { color: 'primary', onClick: _showMore, children: showMoreLocalizedValue === 'show_more' ? 'Show more' : showMoreLocalizedValue })) : (_jsx(Button, { onClick: _showLess, children: showlessLocalizedValue === 'show_less' ? 'Show less' : showlessLocalizedValue })) })), _jsx(Snackbar, { open: showSnackbar, autoHideDuration: 3000, onClose: handleSnackbarClose, message: snackbarMessage, action: _jsx(IconButton, { size: 'small', "aria-label": 'close', color: 'inherit', onClick: handleSnackbarClose, children: _jsx(CloseIcon, { fontSize: 'small' }) }) })] }));
}
//# sourceMappingURL=ToDo.js.map